@@ -1,4 +1,4 @@
-# $Id: XMLNewsNITF.pm,v 1.3 2000/05/19 15:47:13 matt Exp $
+# $Id: XMLNewsNITF.pm,v 1.4 2000/06/02 13:41:50 matt Exp $
 
 package Apache::AxKit::Language::XMLNewsNITF;
 
@@ -12,13 +12,13 @@ use Apache::AxKit::Language;
 
 sub handler {
 	my $class = shift;
-	my ($r, $xmlfile, $stylefile) = @_;
+	my ($r, $xml, $style) = @_;
 	
 	my $template_processor = XMLNews::HTMLTemplate->new();
 	
-	$template_processor->readTemplate($stylefile);
+	$template_processor->readTemplate($style->get_fh());
 	
-	$template_processor->applyTemplate(*STDOUT, $xmlfile, undef);
+	$template_processor->applyTemplate(*STDOUT, $xml->get_fh(), undef);
 	
 	return OK;
 }
